@@ -10,7 +10,7 @@
 #ifndef __TEMPLATE_ALREADY_INCLUDED__
 
 /* the Linux kernel does something similar to assert at compile time */
-#define static_assert(x) (void)( sizeof( int[ 1 - 2* !(x) ]) )
+#define static_assert_fftw(x) (void)( sizeof( int[ 1 - 2* !(x) ]) )
 
 #define __TEMPLATE_ALREADY_INCLUDED__
 #endif
@@ -18,7 +18,7 @@
 
 {
   // make sure the PDL data type I'm using matches the FFTW data type
-  static_assert( sizeof($GENERIC())*2 == sizeof($TFD(fftwf_,fftw_)complex) );
+  static_assert_fftw( sizeof($GENERIC())*2 == sizeof($TFD(fftwf_,fftw_)complex) );
 
   $TFD(fftwf_,fftw_)plan plan = INT2PTR( $TFD(fftwf_,fftw_)plan, $COMP(plan));
 
